# uniq

output one copy of each line in input.txt

    uniq input.txt


count occurrences of lines

    uniq -c count.txt


output only lines that are duplicated

    uniq -d repeats.txt


output only the lines that are not repeated in unique.txt

    uniq -u unique.txt


output unique lines ignoring case

    uniq -i case.txt



# Basic Usage

Output a single copy of each unique line in a file:

    uniq <file>


